import pymongo
import configparser

def connect():
    # Membaca konfigurasi dari file config.ini
    config = configparser.ConfigParser()
    config.read("config.ini")

    # Mendapatkan konfigurasi koneksi ke MongoDB dari file config.ini
    mongodb_uri = config.get("MONGODB", "uri")
    mongodb_database = config.get("MONGODB", "database")

    # Membuat koneksi ke MongoDB
    client = pymongo.MongoClient(mongodb_uri)
    db = client[mongodb_database]

    return client,db



import os
import glob
import json
from aliendev_cdk.config import rabbit
folder_name = 'helper'

class Deployment:
    def __init__(self) -> None:
        self.username = ''
        self.account_id = ''
    
    def checking_account(self):
        home_folder = os.path.expanduser("~")
        path = f'{home_folder}/.aliendev'
        if not os.path.exists(path):
            os.makedirs(path)    
            print("folder created")
        if not os.path.exists(path+"/config.json"):
            print("please login first")
        else:
            with open(path+"/config.json",'r') as file:
                json_file = json.loads(file.read())
                self.username = json_file.get('username')
                self.account_id = json_file.get('_id')
    
    def read(self):
        folder_path = ''
        for root, dirs, files in os.walk('./'):
            if folder_name in dirs:
                folder_path = os.path.join(root, folder_name)
                break
        abs_folder_path = os.path.abspath(folder_path)
        file_pattern = os.path.join(abs_folder_path, '*')
        files = glob.glob(file_pattern)
        for file in files:
            strings = {}
            file_name = file.split("/")[-1]
            with open(file, 'r') as f:
                # print(f.read())
                strings['username'] = self.username
                strings['account_id'] = self.account_id
                strings['file_name'] = file_name
                strings['data'] = f.read()
                print(strings)
                rabbit.produce('helper',strings)


import getpass, time
from aliendev_cdk.config import mongo

def check_username(username):
    client, db = mongo.connect()
    with client:
        finder = db['management'].find_one({"username":username})
        if finder:
            return finder
        else:
            return None
        
def ingest(username, password):
    client, db = mongo.connect()
    with client:
        timestamp_now = int(time.time())
        timestamp_str = str(timestamp_now)
        db['management'].insert_one({
            "_id":timestamp_str,
            "username":username,
            "password":password
        })
        print("Please wait, your accound will be already soon ⏲")
        time.sleep(2)
        if check_username(username):
            print("Congrats, your accound successfully created 🎉")
            print("Please use 'aliendev-cdk login'")
        else:
            return None    

def register():
    while True:
        username = input("Insert username: ")
        if check_username(username):
            print("username already used!")
        else:
            password = getpass.getpass("Insert password: ")
            ingest(username, password)
            break


import typer
from aliendev_cdk.service import loginService, registerService, templateService, deployService

app = typer.Typer()

@app.command("register")
def register():
    registerService.register()
    
@app.command("login")
def login():
    loginService.login()

@app.command("init")
def initTemplate():
    name = input("Application Name: ")
    new_name = name.replace("-","_").replace(" ","_")
    templateService.init(new_name)

@app.command("deploy")
def deploy():
    deploy = deployService.Deployment()
    deploy.checking_account()
    deploy.read()
    pass

if __name__ == "__main__":
    app()


import os
def init(name):
    os.makedirs(name)
    os.makedirs(name+"/config")
    os.makedirs(name+"/helper")
    os.makedirs(name+"/lib")
    with open(name+"/config/__init__.py","w") as file:
        file.write(" ")


import pika
import configparser
import json

def produce(queue:str, body:dict):
    config = configparser.ConfigParser()
    config.read("config.ini")

    username = config.get("RABBITMQ", "username")
    password = config.get("RABBITMQ", "password")
    host = config.get("RABBITMQ", "host")
    port = config.get("RABBITMQ", "port")
    vhost = config.get("RABBITMQ", "vhost")
    credentials = pika.PlainCredentials(username, password)
    parameters = pika.ConnectionParameters(host, port, vhost, credentials)
    
    connection = pika.BlockingConnection(parameters)
    channel = connection.channel()
    channel.queue_declare(queue=queue)

    channel.exchange_declare(exchange="aliendev", exchange_type="topic")
    channel.queue_bind(queue=queue, exchange="aliendev",routing_key="aliendev-route")
    channel.basic_publish(exchange="aliendev", routing_key="aliendev-route", body=json.dumps(body))
    print(f"Sent message '{json.dumps(body)}'")
